- ...

0.6.4 (2011-3-11)
-------------------

- run_gunicorn can set pidfile

0.6.3 (2011-2-26)
-------------------

- fixed gunicorn support, compact with version gunicorn 0.12.0 and earlier.

0.6.2 (2011-2-26)
-------------------

- fixed runfcgi use port

0.6.1  (2010-11-18)
--------------------

- fixed documents.

- fixed unix domain socket support in runfcgi (thks César H. Roldán) .

0.6  (2010-10-21)
--------------------

- add an decorator

- change the shebang from `#!/usr/bin/env python` to `!#/usr/bin/env python2` for archlinux compatible

- add many server support (see documents)

0.5.5 (2010-10-17)
---------------------

- change the structure of flask skeleton

0.5.4 (2010-10-17)
---------------------

- fix missing files. thks Low Kian Seong .

0.5.3 (2010-10-06)
---------------------

- add show_urls action


0.5.2 (2010-09-28)
----------------------

- change the structure of flask skeleton

- add compile_pyc and clean actions
